# ExtFormFieldUnknown


## Properties

Name | Type | Description | Notes
------------ | ------------- | ------------- | -------------
**description** | **str** |  | [optional] 
**label_name** | **str** |  | [optional] 

## Example

```python
from src.client.generated.models.ext_form_field_unknown import ExtFormFieldUnknown

# TODO update the JSON string below
json = "{}"
# create an instance of ExtFormFieldUnknown from a JSON string
ext_form_field_unknown_instance = ExtFormFieldUnknown.from_json(json)
# print the JSON string representation of the object
print(ExtFormFieldUnknown.to_json())

# convert the object into a dict
ext_form_field_unknown_dict = ext_form_field_unknown_instance.to_dict()
# create an instance of ExtFormFieldUnknown from a dict
ext_form_field_unknown_from_dict = ExtFormFieldUnknown.from_dict(ext_form_field_unknown_dict)
```
[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)


